You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@aurora.apache.org by wf...@apache.org on 2013/12/31 22:28:06 UTC

[5/9] Refactors java and python code to the Apache namespace.

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/client/bin/aurora_client.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/client/bin/aurora_client.py b/src/main/python/apache/aurora/client/bin/aurora_client.py
index 8228b88..1523912 100644
--- a/src/main/python/apache/aurora/client/bin/aurora_client.py
+++ b/src/main/python/apache/aurora/client/bin/aurora_client.py
@@ -1,4 +1,4 @@
-from twitter.aurora.client.base import generate_terse_usage
+from apache.aurora.client.base import generate_terse_usage
 from twitter.common import app
 from twitter.common.log.options import LogOptions
 
@@ -6,13 +6,13 @@ from twitter.common.log.options import LogOptions
 # app.command.  This is a poor code practice and should be fixed long-term
 # with the creation of twitter.common.cli that allows for argparse-style CLI
 # composition.
-from twitter.aurora.client.commands import (
+from apache.aurora.client.commands import (
     core,
     help,
     run,
     ssh,
 )
-from twitter.aurora.client.options import add_verbosity_options
+from apache.aurora.client.options import add_verbosity_options
 
 app.register_commands_from(core, run, ssh)
 app.register_commands_from(help)

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/client/cli/BUILD
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/client/cli/BUILD b/src/main/python/apache/aurora/client/cli/BUILD
index 0a44a21..f18c1cd 100644
--- a/src/main/python/apache/aurora/client/cli/BUILD
+++ b/src/main/python/apache/aurora/client/cli/BUILD
@@ -1,7 +1,7 @@
 
 python_binary(
   name='client',
-  entry_point = 'twitter.aurora.cli:main',
+  entry_point = 'apache.aurora.cli:main',
   dependencies = [ pants(':cli') ],
   )
 
@@ -10,17 +10,17 @@ python_library(
   sources = [ '__init__.py', 'context.py', 'jobs.py', 'options.py' ],
   dependencies = [
     pants('aurora/twitterdeps/src/python/twitter/common/python'),
-    pants('src/main/python/twitter/aurora/client/api:command_runner'),
-    pants('src/main/python/twitter/aurora/client/api:disambiguator'),
-    pants('src/main/python/twitter/aurora/client/api:job_monitor'),
-    pants('src/main/python/twitter/aurora/client/api:updater'),
-    pants('src/main/python/twitter/aurora/client/hooks'),
-    pants('src/main/python/twitter/aurora/client:base'),
-    pants('src/main/python/twitter/aurora/client:config'),
-    pants('src/main/python/twitter/aurora/client:factory'),
-    pants('src/main/python/twitter/aurora/client:options'),
-    pants('src/main/python/twitter/aurora/common'),
-    pants('src/main/thrift/com/twitter/aurora/gen:py-thrift'),
-    pants('src/main/python/twitter/aurora:argparse')
+    pants('src/main/python/apache/aurora/client/api:command_runner'),
+    pants('src/main/python/apache/aurora/client/api:disambiguator'),
+    pants('src/main/python/apache/aurora/client/api:job_monitor'),
+    pants('src/main/python/apache/aurora/client/api:updater'),
+    pants('src/main/python/apache/aurora/client/hooks'),
+    pants('src/main/python/apache/aurora/client:base'),
+    pants('src/main/python/apache/aurora/client:config'),
+    pants('src/main/python/apache/aurora/client:factory'),
+    pants('src/main/python/apache/aurora/client:options'),
+    pants('src/main/python/apache/aurora/common'),
+    pants('src/main/thrift/org/apache/aurora/gen:py-thrift'),
+    pants('src/main/python/apache/aurora:argparse')
     ]
   )

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/client/cli/context.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/client/cli/context.py b/src/main/python/apache/aurora/client/cli/context.py
index 2ae92ec..c50f1a1 100644
--- a/src/main/python/apache/aurora/client/cli/context.py
+++ b/src/main/python/apache/aurora/client/cli/context.py
@@ -1,11 +1,11 @@
 
-from twitter.aurora.client.base import synthesize_url
-from twitter.aurora.client.cli import Context, EXIT_NETWORK_ERROR
-from twitter.aurora.client.config import get_config
-from twitter.aurora.client.factory import make_client
+from apache.aurora.client.base import synthesize_url
+from apache.aurora.client.cli import Context, EXIT_NETWORK_ERROR
+from apache.aurora.client.config import get_config
+from apache.aurora.client.factory import make_client
 from twitter.common import log
 
-from gen.twitter.aurora.ttypes import ResponseCode
+from gen.apache.aurora.ttypes import ResponseCode
 
 
 class AuroraCommandContext(Context):

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/client/cli/jobs.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/client/cli/jobs.py b/src/main/python/apache/aurora/client/cli/jobs.py
index e66f181..b789361 100644
--- a/src/main/python/apache/aurora/client/cli/jobs.py
+++ b/src/main/python/apache/aurora/client/cli/jobs.py
@@ -1,18 +1,18 @@
-from twitter.aurora.client.api.job_monitor import JobMonitor
-from twitter.aurora.client.cli import (
+from apache.aurora.client.api.job_monitor import JobMonitor
+from apache.aurora.client.cli import (
     EXIT_INVALID_CONFIGURATION,
     Noun,
     Verb
 )
-from twitter.aurora.client.cli.context import AuroraCommandContext
-from twitter.aurora.client.cli.options import (
+from apache.aurora.client.cli.context import AuroraCommandContext
+from apache.aurora.client.cli.options import (
     BIND_OPTION,
     BROWSER_OPTION,
     CONFIG_OPTION,
     JOBSPEC_OPTION,
     JSON_OPTION
 )
-from twitter.aurora.common.aurora_job_key import AuroraJobKey
+from apache.aurora.common.aurora_job_key import AuroraJobKey
 
 from pystachio.config import Config
 

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/client/cli/options.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/client/cli/options.py b/src/main/python/apache/aurora/client/cli/options.py
index 64a58f8..80fabb9 100644
--- a/src/main/python/apache/aurora/client/cli/options.py
+++ b/src/main/python/apache/aurora/client/cli/options.py
@@ -1,5 +1,5 @@
-from twitter.aurora.client.cli import CommandOption
-from twitter.aurora.common.aurora_job_key import AuroraJobKey
+from apache.aurora.client.cli import CommandOption
+from apache.aurora.common.aurora_job_key import AuroraJobKey
 
 
 BIND_OPTION = CommandOption('--bind', type=str, default=[], dest='bindings',

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/client/commands/BUILD
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/client/commands/BUILD b/src/main/python/apache/aurora/client/commands/BUILD
index 3bcb6fd..556d00a 100644
--- a/src/main/python/apache/aurora/client/commands/BUILD
+++ b/src/main/python/apache/aurora/client/commands/BUILD
@@ -15,11 +15,11 @@ python_library(
     pants('aurora/twitterdeps/src/python/twitter/common/app'),
     pants('aurora/twitterdeps/src/python/twitter/common/log'),
     pants('aurora/twitterdeps/src/python/twitter/common/quantity'),
-    pants('src/main/python/twitter/aurora/admin:mesos_maintenance'),
-    pants('src/main/python/twitter/aurora/client/api'),
-    pants('src/main/python/twitter/aurora/client:base'),
-    pants('src/main/python/twitter/aurora/common:clusters'),
-    pants('src/main/thrift/com/twitter/aurora/gen:py-thrift'),
+    pants('src/main/python/apache/aurora/admin:mesos_maintenance'),
+    pants('src/main/python/apache/aurora/client/api'),
+    pants('src/main/python/apache/aurora/client:base'),
+    pants('src/main/python/apache/aurora/common:clusters'),
+    pants('src/main/thrift/org/apache/aurora/gen:py-thrift'),
   ]
 )
 
@@ -30,17 +30,17 @@ python_library(
     pants('aurora/twitterdeps/src/python/twitter/common/app'),
     pants('aurora/twitterdeps/src/python/twitter/common/log'),
     pants('aurora/twitterdeps/src/python/twitter/common/python'),
-    pants('src/main/python/twitter/aurora/client/api:command_runner'),
-    pants('src/main/python/twitter/aurora/client/api:disambiguator'),
-    pants('src/main/python/twitter/aurora/client/api:job_monitor'),
-    pants('src/main/python/twitter/aurora/client/api:updater'),
-    pants('src/main/python/twitter/aurora/client/hooks'),
-    pants('src/main/python/twitter/aurora/client:base'),
-    pants('src/main/python/twitter/aurora/client:config'),
-    pants('src/main/python/twitter/aurora/client:factory'),
-    pants('src/main/python/twitter/aurora/client:options'),
-    pants('src/main/python/twitter/aurora/common'),
-    pants('src/main/thrift/com/twitter/aurora/gen:py-thrift'),
+    pants('src/main/python/apache/aurora/client/api:command_runner'),
+    pants('src/main/python/apache/aurora/client/api:disambiguator'),
+    pants('src/main/python/apache/aurora/client/api:job_monitor'),
+    pants('src/main/python/apache/aurora/client/api:updater'),
+    pants('src/main/python/apache/aurora/client/hooks'),
+    pants('src/main/python/apache/aurora/client:base'),
+    pants('src/main/python/apache/aurora/client:config'),
+    pants('src/main/python/apache/aurora/client:factory'),
+    pants('src/main/python/apache/aurora/client:options'),
+    pants('src/main/python/apache/aurora/common'),
+    pants('src/main/thrift/org/apache/aurora/gen:py-thrift'),
   ]
 )
 
@@ -49,7 +49,7 @@ python_library(
   sources = ['help.py'],
   dependencies = [
     pants('aurora/twitterdeps/src/python/twitter/common/app'),
-    pants('src/main/python/twitter/aurora/client:base'),
+    pants('src/main/python/apache/aurora/client:base'),
   ]
 )
 
@@ -58,11 +58,11 @@ python_library(
   sources = ['run.py'],
   dependencies = [
     pants('aurora/twitterdeps/src/python/twitter/common/app'),
-    pants('src/main/python/twitter/aurora/client/api:command_runner'),
-    pants('src/main/python/twitter/aurora/client:base'),
-    pants('src/main/python/twitter/aurora/client:options'),
-    pants('src/main/python/twitter/aurora/common:aurora_job_key'),
-    pants('src/main/python/twitter/aurora/common:clusters'),
+    pants('src/main/python/apache/aurora/client/api:command_runner'),
+    pants('src/main/python/apache/aurora/client:base'),
+    pants('src/main/python/apache/aurora/client:options'),
+    pants('src/main/python/apache/aurora/common:aurora_job_key'),
+    pants('src/main/python/apache/aurora/common:clusters'),
   ]
 )
 
@@ -71,11 +71,11 @@ python_library(
   sources = ['ssh.py'],
   dependencies = [
     pants('aurora/twitterdeps/src/python/twitter/common/app'),
-    pants('src/main/python/twitter/aurora/client/api:command_runner'),
-    pants('src/main/python/twitter/aurora/client:base'),
-    pants('src/main/python/twitter/aurora/client:factory'),
-    pants('src/main/python/twitter/aurora/client:options'),
-    pants('src/main/python/twitter/aurora/common:aurora_job_key'),
-    pants('src/main/python/twitter/aurora/common:clusters'),
+    pants('src/main/python/apache/aurora/client/api:command_runner'),
+    pants('src/main/python/apache/aurora/client:base'),
+    pants('src/main/python/apache/aurora/client:factory'),
+    pants('src/main/python/apache/aurora/client:options'),
+    pants('src/main/python/apache/aurora/common:aurora_job_key'),
+    pants('src/main/python/apache/aurora/common:clusters'),
   ]
 )

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/client/commands/admin.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/client/commands/admin.py b/src/main/python/apache/aurora/client/commands/admin.py
index c1c9c42..15e25d5 100644
--- a/src/main/python/apache/aurora/client/commands/admin.py
+++ b/src/main/python/apache/aurora/client/commands/admin.py
@@ -7,16 +7,16 @@ import os
 import optparse
 import subprocess
 
-from twitter.aurora.admin.mesos_maintenance import MesosMaintenance
-from twitter.aurora.client.api import AuroraClientAPI
-from twitter.aurora.client.base import check_and_log_response, die, requires
-from twitter.aurora.common.clusters import CLUSTERS
+from apache.aurora.admin.mesos_maintenance import MesosMaintenance
+from apache.aurora.client.api import AuroraClientAPI
+from apache.aurora.client.base import check_and_log_response, die, requires
+from apache.aurora.common.clusters import CLUSTERS
 from twitter.common import app, log
 from twitter.common.quantity import Amount, Data
 from twitter.common.quantity.parse_simple import parse_data
 
-from gen.twitter.aurora.constants import ACTIVE_STATES, TERMINAL_STATES
-from gen.twitter.aurora.ttypes import (
+from gen.apache.aurora.constants import ACTIVE_STATES, TERMINAL_STATES
+from gen.apache.aurora.ttypes import (
     ResponseCode,
     ScheduleStatus,
     TaskQuery,

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/client/commands/core.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/client/commands/core.py b/src/main/python/apache/aurora/client/commands/core.py
index 712c7ea..45204b5 100644
--- a/src/main/python/apache/aurora/client/commands/core.py
+++ b/src/main/python/apache/aurora/client/commands/core.py
@@ -17,19 +17,19 @@ from twitter.common import app, log
 from twitter.common.python.pex import PexInfo
 from twitter.common.python.dirwrapper import PythonDirectoryWrapper
 
-from twitter.aurora.client.base import (
+from apache.aurora.client.base import (
     check_and_log_response,
     deprecation_warning,
     die,
     handle_open,
     requires,
     synthesize_url)
-from twitter.aurora.client.api.disambiguator import LiveJobDisambiguator
-from twitter.aurora.client.api.job_monitor import JobMonitor
-from twitter.aurora.client.api.updater_util import UpdaterConfig
-from twitter.aurora.client.config import get_config
-from twitter.aurora.client.factory import make_client, make_client_factory
-from twitter.aurora.client.options import (
+from apache.aurora.client.api.disambiguator import LiveJobDisambiguator
+from apache.aurora.client.api.job_monitor import JobMonitor
+from apache.aurora.client.api.updater_util import UpdaterConfig
+from apache.aurora.client.config import get_config
+from apache.aurora.client.factory import make_client, make_client_factory
+from apache.aurora.client.options import (
     CLUSTER_CONFIG_OPTION,
     CLUSTER_INVOKE_OPTION,
     ENV_CONFIG_OPTION,
@@ -40,10 +40,10 @@ from twitter.aurora.client.options import (
     OPEN_BROWSER_OPTION,
     SHARDS_OPTION,
     WAIT_UNTIL_OPTION)
-from twitter.aurora.common.aurora_job_key import AuroraJobKey
+from apache.aurora.common.aurora_job_key import AuroraJobKey
 
-from gen.twitter.aurora.constants import ACTIVE_STATES, CURRENT_API_VERSION, AURORA_EXECUTOR_NAME
-from gen.twitter.aurora.ttypes import ExecutorConfig, ResponseCode, ScheduleStatus
+from gen.apache.aurora.constants import ACTIVE_STATES, CURRENT_API_VERSION, AURORA_EXECUTOR_NAME
+from gen.apache.aurora.ttypes import ExecutorConfig, ResponseCode, ScheduleStatus
 
 
 def get_job_config(job_spec, config_file, options):

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/client/commands/help.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/client/commands/help.py b/src/main/python/apache/aurora/client/commands/help.py
index a74c607..20823b4 100644
--- a/src/main/python/apache/aurora/client/commands/help.py
+++ b/src/main/python/apache/aurora/client/commands/help.py
@@ -3,7 +3,7 @@ from __future__ import print_function
 import collections
 import sys
 
-from twitter.aurora.client.base import die
+from apache.aurora.client.base import die
 from twitter.common import app
 
 

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/client/commands/run.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/client/commands/run.py b/src/main/python/apache/aurora/client/commands/run.py
index 494ce47..60f127c 100644
--- a/src/main/python/apache/aurora/client/commands/run.py
+++ b/src/main/python/apache/aurora/client/commands/run.py
@@ -1,12 +1,12 @@
 from twitter.common import app
-from twitter.aurora.client.base import die
-from twitter.aurora.client.options import (
+from apache.aurora.client.base import die
+from apache.aurora.client.options import (
     EXECUTOR_SANDBOX_OPTION,
     SSH_USER_OPTION,
 )
-from twitter.aurora.common.aurora_job_key import AuroraJobKey
-from twitter.aurora.common.clusters import CLUSTERS
-from twitter.aurora.client.api.command_runner import DistributedCommandRunner
+from apache.aurora.common.aurora_job_key import AuroraJobKey
+from apache.aurora.common.clusters import CLUSTERS
+from apache.aurora.client.api.command_runner import DistributedCommandRunner
 
 
 @app.command

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/client/commands/ssh.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/client/commands/ssh.py b/src/main/python/apache/aurora/client/commands/ssh.py
index 109229f..7aa767f 100644
--- a/src/main/python/apache/aurora/client/commands/ssh.py
+++ b/src/main/python/apache/aurora/client/commands/ssh.py
@@ -1,14 +1,14 @@
 import subprocess
 
 from twitter.common import app
-from twitter.aurora.client.base import check_and_log_response, die
-from twitter.aurora.client.factory import make_client
-from twitter.aurora.client.options import (
+from apache.aurora.client.base import check_and_log_response, die
+from apache.aurora.client.factory import make_client
+from apache.aurora.client.options import (
     EXECUTOR_SANDBOX_OPTION,
     SSH_USER_OPTION,
 )
-from twitter.aurora.common.aurora_job_key import AuroraJobKey
-from twitter.aurora.client.api.command_runner import DistributedCommandRunner
+from apache.aurora.common.aurora_job_key import AuroraJobKey
+from apache.aurora.client.api.command_runner import DistributedCommandRunner
 
 
 @app.command

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/client/config.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/client/config.py b/src/main/python/apache/aurora/client/config.py
index 32df4eb..2a78f42 100644
--- a/src/main/python/apache/aurora/client/config.py
+++ b/src/main/python/apache/aurora/client/config.py
@@ -11,12 +11,12 @@ import sys
 
 from twitter.common import app, log
 
-from twitter.aurora.client import binding_helper
-from twitter.aurora.client.base import deprecation_warning, die
-from twitter.aurora.config import AuroraConfig
-from twitter.thermos.config.schema_helpers import Tasks
+from apache.aurora.client import binding_helper
+from apache.aurora.client.base import deprecation_warning, die
+from apache.aurora.config import AuroraConfig
+from apache.thermos.config.schema_helpers import Tasks
 
-from gen.twitter.aurora.constants import DEFAULT_ENVIRONMENT
+from gen.apache.aurora.constants import DEFAULT_ENVIRONMENT
 
 from pystachio import Empty, Ref
 

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/client/factory.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/client/factory.py b/src/main/python/apache/aurora/client/factory.py
index 7a44e3b..e64c1a7 100644
--- a/src/main/python/apache/aurora/client/factory.py
+++ b/src/main/python/apache/aurora/client/factory.py
@@ -1,8 +1,8 @@
 import functools
 
-from twitter.aurora.client.hooks.hooked_api import HookedAuroraClientAPI
-from twitter.aurora.common.cluster import Cluster
-from twitter.aurora.common.clusters import CLUSTERS
+from apache.aurora.client.hooks.hooked_api import HookedAuroraClientAPI
+from apache.aurora.common.cluster import Cluster
+from apache.aurora.common.clusters import CLUSTERS
 from twitter.common import app
 
 from .base import die

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/client/hooks/BUILD
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/client/hooks/BUILD b/src/main/python/apache/aurora/client/hooks/BUILD
index c3d0a1a..3feb81b 100644
--- a/src/main/python/apache/aurora/client/hooks/BUILD
+++ b/src/main/python/apache/aurora/client/hooks/BUILD
@@ -3,8 +3,8 @@ python_library(
   sources = ['__init__.py', 'hooked_api.py'],
   dependencies = [
     pants('aurora/twitterdeps/src/python/twitter/common/log'),
-    pants('src/main/python/twitter/aurora/client:api'),
-    pants('src/main/python/twitter/aurora/common:aurora_job_key'),
-    pants('src/main/thrift/com/twitter/aurora/gen:py-thrift'),
+    pants('src/main/python/apache/aurora/client:api'),
+    pants('src/main/python/apache/aurora/common:aurora_job_key'),
+    pants('src/main/thrift/org/apache/aurora/gen:py-thrift'),
   ]
 )

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/client/hooks/hooked_api.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/client/options.py b/src/main/python/apache/aurora/client/options.py
index 7ced961..af56351 100644
--- a/src/main/python/apache/aurora/client/options.py
+++ b/src/main/python/apache/aurora/client/options.py
@@ -1,7 +1,7 @@
 import optparse
 
-from twitter.aurora.common.aurora_job_key import AuroraJobKey
-from twitter.thermos.common.options import add_binding_to
+from apache.aurora.common.aurora_job_key import AuroraJobKey
+from apache.thermos.common.options import add_binding_to
 
 
 __all__ = (

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/common/BUILD
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/common/BUILD b/src/main/python/apache/aurora/common/BUILD
index 4e839f7..9da66aa 100644
--- a/src/main/python/apache/aurora/common/BUILD
+++ b/src/main/python/apache/aurora/common/BUILD
@@ -5,7 +5,7 @@ python_library(
   sources = ['aurora_job_key.py'],
   dependencies = [
     pants('aurora/twitterdeps/src/python/twitter/common/lang'),
-    pants('src/main/thrift/com/twitter/aurora/gen:py-thrift'),
+    pants('src/main/thrift/org/apache/aurora/gen:py-thrift'),
   ]
 )
 
@@ -13,7 +13,7 @@ python_library(
   name = 'cluster',
   sources = ['cluster.py'],
   dependencies = [
-    pants('src/main/python/twitter/aurora/BUILD.thirdparty:pystachio'),
+    pants('src/main/python/apache/aurora/BUILD.thirdparty:pystachio'),
   ]
 )
 
@@ -22,7 +22,7 @@ python_library(
   sources = ['clusters.py'],
   dependencies = [
     pants(':cluster'),
-    pants('src/main/python/twitter/aurora/BUILD.thirdparty:pystachio'),
+    pants('src/main/python/apache/aurora/BUILD.thirdparty:pystachio'),
     pants('aurora/twitterdeps/src/python/twitter/common/collections'),
   ]
 )
@@ -52,10 +52,10 @@ python_library(
     pants(':cluster_option'),
     pants(':clusters'),
     pants(':http_signaler'),
-    pants('src/main/python/twitter/aurora/common/auth'),
+    pants('src/main/python/apache/aurora/common/auth'),
   ],
   provides = setup_py(
-    name = 'twitter.aurora.common',
+    name = 'apache.aurora.common',
     version = open(os.path.join(get_buildroot(), '.auroraversion')).read().strip().lower(),
     description = 'Aurora common libraries.',
     license = 'Apache License, Version 2.0',

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/common/aurora_job_key.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/common/aurora_job_key.py b/src/main/python/apache/aurora/common/aurora_job_key.py
index 81a8687..70b5eb4 100644
--- a/src/main/python/apache/aurora/common/aurora_job_key.py
+++ b/src/main/python/apache/aurora/common/aurora_job_key.py
@@ -2,8 +2,8 @@ import re
 
 from twitter.common.lang import Compatibility, total_ordering
 
-from gen.twitter.aurora.constants import GOOD_IDENTIFIER_PATTERN_PYTHON
-from gen.twitter.aurora.ttypes import Identity, JobKey, TaskQuery
+from gen.apache.aurora.constants import GOOD_IDENTIFIER_PATTERN_PYTHON
+from gen.apache.aurora.ttypes import Identity, JobKey, TaskQuery
 
 # TODO(ksweeney): This can just probably just extend namedtuple.
 @total_ordering

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/common/auth/BUILD
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/common/auth/BUILD b/src/main/python/apache/aurora/common/auth/BUILD
index fd5b024..277620b 100644
--- a/src/main/python/apache/aurora/common/auth/BUILD
+++ b/src/main/python/apache/aurora/common/auth/BUILD
@@ -4,6 +4,6 @@ python_library(
   dependencies = [
     pants('aurora/twitterdeps/src/python/twitter/common/lang'),
     pants('aurora/twitterdeps/src/python/twitter/common/log'),
-    pants('src/main/thrift/com/twitter/aurora/gen:py-thrift'),
+    pants('src/main/thrift/org/apache/aurora/gen:py-thrift'),
   ]
 )

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/common/auth/auth_module.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/common/auth/auth_module.py b/src/main/python/apache/aurora/common/auth/auth_module.py
index 7b146a9..0061a30 100644
--- a/src/main/python/apache/aurora/common/auth/auth_module.py
+++ b/src/main/python/apache/aurora/common/auth/auth_module.py
@@ -5,7 +5,7 @@ import time
 
 from twitter.common.lang import Interface
 
-from gen.twitter.aurora.ttypes import SessionKey
+from gen.apache.aurora.ttypes import SessionKey
 
 
 class AuthModule(Interface):

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/common/auth/auth_module_manager.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/common/auth/auth_module_manager.py b/src/main/python/apache/aurora/common/auth/auth_module_manager.py
index 03d51b3..a025c6b 100644
--- a/src/main/python/apache/aurora/common/auth/auth_module_manager.py
+++ b/src/main/python/apache/aurora/common/auth/auth_module_manager.py
@@ -1,6 +1,6 @@
 from twitter.common import log
 
-from gen.twitter.aurora.ttypes import SessionKey
+from gen.apache.aurora.ttypes import SessionKey
 
 from .auth_module import AuthModule, InsecureAuthModule
 

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/config/BUILD
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/config/BUILD b/src/main/python/apache/aurora/config/BUILD
index 91cb3e4..58a0ab1 100644
--- a/src/main/python/apache/aurora/config/BUILD
+++ b/src/main/python/apache/aurora/config/BUILD
@@ -1,10 +1,10 @@
 import os
 
-# Alias for src/main/python/twitter/aurora/config/schema
+# Alias for src/main/python/apache/aurora/config/schema
 python_library(
   name = 'schema',
   dependencies = [
-    pants('src/main/python/twitter/aurora/config/schema'),
+    pants('src/main/python/apache/aurora/config/schema'),
   ]
 )
 
@@ -17,11 +17,11 @@ python_library(
     'thrift.py',
   ),
   dependencies = [
-    pants('src/main/python/twitter/aurora/BUILD.thirdparty:pystachio'),
+    pants('src/main/python/apache/aurora/BUILD.thirdparty:pystachio'),
     pants('aurora/twitterdeps/src/python/twitter/common/lang'),
-    pants('src/main/python/twitter/aurora/common'),
-    pants('src/main/python/twitter/aurora/config/schema'),
-    pants('src/main/thrift/com/twitter/aurora/gen:py-thrift'),
+    pants('src/main/python/apache/aurora/common'),
+    pants('src/main/python/apache/aurora/config/schema'),
+    pants('src/main/thrift/org/apache/aurora/gen:py-thrift'),
   ],
 
 )
@@ -32,10 +32,10 @@ python_library(
     pants(':config'),
 
     # covering dependencies
-    pants('src/main/python/twitter/thermos/config'),
+    pants('src/main/python/apache/thermos/config'),
   ],
   provides = setup_py(
-    name = 'twitter.aurora.config',
+    name = 'apache.aurora.config',
     version = open(os.path.join(get_buildroot(), '.auroraversion')).read().strip().lower(),
     description = 'Aurora/Thermos Pystachio schemas for describing job configurations.',
     license = 'Apache License, Version 2.0',

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/config/__init__.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/config/__init__.py b/src/main/python/apache/aurora/config/__init__.py
index a3ba981..7d4d485 100644
--- a/src/main/python/apache/aurora/config/__init__.py
+++ b/src/main/python/apache/aurora/config/__init__.py
@@ -2,10 +2,10 @@ from __future__ import absolute_import
 
 from collections import defaultdict
 
-from twitter.aurora.common.aurora_job_key import AuroraJobKey
-from twitter.aurora.config.schema.base import MesosContext
-from twitter.thermos.config.loader import PortExtractor, ThermosTaskWrapper
-from twitter.thermos.config.schema import ThermosContext
+from apache.aurora.common.aurora_job_key import AuroraJobKey
+from apache.aurora.config.schema.base import MesosContext
+from apache.thermos.config.loader import PortExtractor, ThermosTaskWrapper
+from apache.thermos.config.schema import ThermosContext
 
 from .loader import AuroraConfigLoader
 from .port_resolver import PortResolver

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/config/loader.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/config/loader.py b/src/main/python/apache/aurora/config/loader.py
index e3e5559..df82530 100644
--- a/src/main/python/apache/aurora/config/loader.py
+++ b/src/main/python/apache/aurora/config/loader.py
@@ -2,7 +2,7 @@ import json
 import pkgutil
 import textwrap
 
-from twitter.aurora.config.schema import base as base_schema
+from apache.aurora.config.schema import base as base_schema
 
 from pystachio.config import Config as PystachioConfig
 

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/config/repl.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/config/repl.py b/src/main/python/apache/aurora/config/repl.py
index d26f94d..e161668 100644
--- a/src/main/python/apache/aurora/config/repl.py
+++ b/src/main/python/apache/aurora/config/repl.py
@@ -1,4 +1,4 @@
-from twitter.aurora.config.loader import AuroraConfigLoader
+from apache.aurora.config.loader import AuroraConfigLoader
 from twitter.common.lang import Compatibility
 
 

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/config/schema/BUILD
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/config/schema/BUILD b/src/main/python/apache/aurora/config/schema/BUILD
index fd08ec7..694fe71 100644
--- a/src/main/python/apache/aurora/config/schema/BUILD
+++ b/src/main/python/apache/aurora/config/schema/BUILD
@@ -2,8 +2,8 @@ python_library(
   name = 'schema',
   sources = ['base.py'],
   dependencies = [
-    pants('src/main/python/twitter/aurora/BUILD.thirdparty:pystachio'),
-    pants('src/main/python/twitter/thermos/config:schema'),
-    pants('src/main/thrift/com/twitter/aurora/gen:py-thrift'),
+    pants('src/main/python/apache/aurora/BUILD.thirdparty:pystachio'),
+    pants('src/main/python/apache/thermos/config:schema'),
+    pants('src/main/thrift/org/apache/aurora/gen:py-thrift'),
   ]
 )

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/config/schema/base.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/config/schema/base.py b/src/main/python/apache/aurora/config/schema/base.py
index b3d437f..7446594 100644
--- a/src/main/python/apache/aurora/config/schema/base.py
+++ b/src/main/python/apache/aurora/config/schema/base.py
@@ -1,6 +1,6 @@
-from twitter.thermos.config.schema import *
+from apache.thermos.config.schema import *
 
-from gen.twitter.aurora.constants import DEFAULT_ENVIRONMENT
+from gen.apache.aurora.constants import DEFAULT_ENVIRONMENT
 
 
 # TODO(wickman) Bind {{mesos.instance}} to %shard_id%

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/config/thrift.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/config/thrift.py b/src/main/python/apache/aurora/config/thrift.py
index 8f6a5ce..acfe961 100644
--- a/src/main/python/apache/aurora/config/thrift.py
+++ b/src/main/python/apache/aurora/config/thrift.py
@@ -1,16 +1,16 @@
 import getpass
 import re
 
-from twitter.aurora.config.schema.base import (
+from apache.aurora.config.schema.base import (
   HealthCheckConfig,
   MesosContext,
   MesosTaskInstance,
 )
 from twitter.common.lang import Compatibility
-from twitter.thermos.config.loader import ThermosTaskValidator
+from apache.thermos.config.loader import ThermosTaskValidator
 
-from gen.twitter.aurora.constants import GOOD_IDENTIFIER_PATTERN_PYTHON, AURORA_EXECUTOR_NAME
-from gen.twitter.aurora.ttypes import (
+from gen.apache.aurora.constants import GOOD_IDENTIFIER_PATTERN_PYTHON, AURORA_EXECUTOR_NAME
+from gen.apache.aurora.ttypes import (
   Constraint,
   CronCollisionPolicy,
   ExecutorConfig,

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/executor/BUILD
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/executor/BUILD b/src/main/python/apache/aurora/executor/BUILD
index 01701e9..8a3413b 100644
--- a/src/main/python/apache/aurora/executor/BUILD
+++ b/src/main/python/apache/aurora/executor/BUILD
@@ -7,14 +7,14 @@ python_library(
     pants('aurora/twitterdeps/src/python/twitter/common/dirutil'),
     pants('aurora/twitterdeps/src/python/twitter/common/log'),
     pants('aurora/twitterdeps/src/python/twitter/common/quantity'),
-    pants('src/main/python/twitter/thermos/common'),
-    pants('src/main/python/twitter/thermos/config:schema'),
-    pants('src/main/python/twitter/thermos/core'),
-    pants('src/main/python/twitter/thermos/monitoring:monitor'),
-    pants('src/main/python/twitter/aurora/common:http_signaler'),
-    pants('src/main/python/twitter/aurora/executor/common:status_checker'),
-    pants('src/main/python/twitter/aurora/executor/common:task_info'),
-    pants('src/main/python/twitter/aurora/executor/common:task_runner'),
+    pants('src/main/python/apache/thermos/common'),
+    pants('src/main/python/apache/thermos/config:schema'),
+    pants('src/main/python/apache/thermos/core'),
+    pants('src/main/python/apache/thermos/monitoring:monitor'),
+    pants('src/main/python/apache/aurora/common:http_signaler'),
+    pants('src/main/python/apache/aurora/executor/common:status_checker'),
+    pants('src/main/python/apache/aurora/executor/common:task_info'),
+    pants('src/main/python/apache/aurora/executor/common:task_runner'),
   ]
 )
 
@@ -30,7 +30,7 @@ python_library(
   name = 'executor_vars',
   sources = ['executor_vars.py'],
   dependencies = [
-    pants('src/main/python/twitter/aurora/BUILD.thirdparty:psutil'),
+    pants('src/main/python/apache/aurora/BUILD.thirdparty:psutil'),
     pants('aurora/twitterdeps/src/python/twitter/common/exceptions'),
     pants('aurora/twitterdeps/src/python/twitter/common/metrics'),
     pants('aurora/twitterdeps/src/python/twitter/common/python'),
@@ -46,7 +46,7 @@ python_library(
     pants('aurora/twitterdeps/src/python/twitter/common/exceptions'),
     pants('aurora/twitterdeps/src/python/twitter/common/log'),
     pants('aurora/twitterdeps/src/python/twitter/common/quantity'),
-    pants('src/main/python/twitter/aurora/executor/common:status_checker'),
+    pants('src/main/python/apache/aurora/executor/common:status_checker'),
   ]
 )
 
@@ -55,9 +55,9 @@ python_library(
   sources = ['executor_base.py'],
   dependencies = [
     pants('aurora/twitterdeps/src/python/twitter/common/log'),
-    pants('src/main/thrift/com/twitter/thermos:py-thrift'),
-    pants('src/main/python/twitter/aurora:mesos-core'),
-    pants('src/main/thrift/com/twitter/aurora/gen:py-thrift'),
+    pants('src/main/thrift/org/apache/thermos:py-thrift'),
+    pants('src/main/python/apache/aurora:mesos-core'),
+    pants('src/main/thrift/org/apache/aurora/gen:py-thrift'),
   ]
 )
 
@@ -65,18 +65,18 @@ python_library(
   name = 'thermos_executor',
   sources = ['thermos_executor.py'],
   dependencies = [
-    pants('src/main/python/twitter/aurora/BUILD.thirdparty:pystachio'),
+    pants('src/main/python/apache/aurora/BUILD.thirdparty:pystachio'),
     pants(':status_manager'),
     pants(':thermos_executor_base'),
     pants('aurora/twitterdeps/src/python/twitter/common/app'),
     pants('aurora/twitterdeps/src/python/twitter/common/concurrent'),
     pants('aurora/twitterdeps/src/python/twitter/common/log'),
     pants('aurora/twitterdeps/src/python/twitter/common/quantity'),
-    pants('src/main/python/twitter/aurora/executor/common:kill_manager'),
-    pants('src/main/python/twitter/aurora/executor/common:sandbox'),
-    pants('src/main/python/twitter/aurora/executor/common:task_info'),
-    pants('src/main/python/twitter/aurora/executor/common:task_runner'),
-    pants('src/main/python/twitter/aurora:mesos-core'),
+    pants('src/main/python/apache/aurora/executor/common:kill_manager'),
+    pants('src/main/python/apache/aurora/executor/common:sandbox'),
+    pants('src/main/python/apache/aurora/executor/common:task_info'),
+    pants('src/main/python/apache/aurora/executor/common:task_runner'),
+    pants('src/main/python/apache/aurora:mesos-core'),
   ]
 )
 
@@ -86,9 +86,9 @@ python_library(
   dependencies = [
     pants('aurora/twitterdeps/src/python/twitter/common/app'),
     pants('aurora/twitterdeps/src/python/twitter/common/log'),
-    pants('src/main/python/twitter/thermos/common:planner'),
-    pants('src/main/python/twitter/thermos/config:schema'),
-    pants('src/main/python/twitter/thermos/core'),
+    pants('src/main/python/apache/thermos/common:planner'),
+    pants('src/main/python/apache/thermos/config:schema'),
+    pants('src/main/python/apache/thermos/core'),
   ],
 )
 
@@ -96,7 +96,7 @@ python_library(
   name = 'gc_executor',
   sources = ['gc_executor.py'],
   dependencies = [
-    pants('src/main/python/twitter/aurora/BUILD.thirdparty:psutil'),
+    pants('src/main/python/apache/aurora/BUILD.thirdparty:psutil'),
     pants(':executor_detector'),
     pants(':thermos_executor_base'),
     pants('aurora/twitterdeps/src/python/twitter/common/collections'),
@@ -104,16 +104,16 @@ python_library(
     pants('aurora/twitterdeps/src/python/twitter/common/log'),
     pants('aurora/twitterdeps/src/python/twitter/common/metrics'),
     pants('aurora/twitterdeps/src/python/twitter/common/quantity'),
-    pants('src/main/python/twitter/thermos/common:ckpt'),
-    pants('src/main/python/twitter/thermos/common:path'),
-    pants('src/main/python/twitter/thermos/core:helper'),
-    pants('src/main/python/twitter/thermos/core:inspector'),
-    pants('src/main/python/twitter/thermos/monitoring:detector'),
-    pants('src/main/python/twitter/thermos/monitoring:garbage'),
-    pants('src/main/python/twitter/aurora/config:schema'),
-    pants('src/main/python/twitter/aurora/executor/common:sandbox'),
-    pants('src/main/python/twitter/aurora:mesos-core'),
-    pants('src/main/thrift/com/twitter/aurora/gen:py-thrift'),
+    pants('src/main/python/apache/thermos/common:ckpt'),
+    pants('src/main/python/apache/thermos/common:path'),
+    pants('src/main/python/apache/thermos/core:helper'),
+    pants('src/main/python/apache/thermos/core:inspector'),
+    pants('src/main/python/apache/thermos/monitoring:detector'),
+    pants('src/main/python/apache/thermos/monitoring:garbage'),
+    pants('src/main/python/apache/aurora/config:schema'),
+    pants('src/main/python/apache/aurora/executor/common:sandbox'),
+    pants('src/main/python/apache/aurora:mesos-core'),
+    pants('src/main/thrift/org/apache/aurora/gen:py-thrift'),
   ]
 )
 
@@ -121,19 +121,19 @@ python_library(
   name = 'executor-packaged',
   dependencies = [
     # Covering dependencies
-    pants('src/main/python/twitter/aurora/common'),
-    pants('src/main/python/twitter/aurora/config'),
-    pants('src/main/python/twitter/thermos/common'),
-    pants('src/main/python/twitter/thermos/config'),
-    pants('src/main/python/twitter/thermos/core'),
-    pants('src/main/python/twitter/thermos/monitoring'),
+    pants('src/main/python/apache/aurora/common'),
+    pants('src/main/python/apache/aurora/config'),
+    pants('src/main/python/apache/thermos/common'),
+    pants('src/main/python/apache/thermos/config'),
+    pants('src/main/python/apache/thermos/core'),
+    pants('src/main/python/apache/thermos/monitoring'),
   ],
   provides = setup_py(
-    name = 'twitter.aurora.executor',
+    name = 'apache.aurora.executor',
     version = open(os.path.join(get_buildroot(), '.auroraversion')).read().strip().lower(),
   ).with_binaries(
-    gc_executor = pants('src/main/python/twitter/aurora/executor/bin:gc_executor'),
-    thermos_executor = pants('src/main/python/twitter/aurora/executor/bin:thermos_executor'),
-    thermos_runner = pants('src/main/python/twitter/aurora/executor/bin:thermos_runner'),
+    gc_executor = pants('src/main/python/apache/aurora/executor/bin:gc_executor'),
+    thermos_executor = pants('src/main/python/apache/aurora/executor/bin:thermos_executor'),
+    thermos_runner = pants('src/main/python/apache/aurora/executor/bin:thermos_runner'),
   )
 )

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/executor/bin/BUILD
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/executor/bin/BUILD b/src/main/python/apache/aurora/executor/bin/BUILD
index 5e9cab1..5ead9ca 100644
--- a/src/main/python/apache/aurora/executor/bin/BUILD
+++ b/src/main/python/apache/aurora/executor/bin/BUILD
@@ -1,47 +1,47 @@
 python_binary(
   name = 'thermos_executor',
   source = 'thermos_executor_main.py',
-  entry_point = 'twitter.aurora.executor.bin.thermos_executor_main:proxy_main',
+  entry_point = 'apache.aurora.executor.bin.thermos_executor_main:proxy_main',
   ignore_errors = True,
   always_write_cache = True,
   dependencies = [
     pants('aurora/twitterdeps/src/python/twitter/common/app'),
     pants('aurora/twitterdeps/src/python/twitter/common/log'),
     pants('aurora/twitterdeps/src/python/twitter/common/metrics'),
-    pants('src/main/python/twitter/aurora/executor/common:executor_timeout'),
-    pants('src/main/python/twitter/aurora/executor/common:health_checker'),
-    pants('src/main/python/twitter/aurora/executor/common:sandbox'),
-    pants('src/main/python/twitter/aurora/executor:executor_detector'),
-    pants('src/main/python/twitter/aurora/executor:executor_vars'),
-    pants('src/main/python/twitter/aurora/executor:thermos_executor'),
-    pants('src/main/python/twitter/aurora/executor:thermos_task_runner'),
+    pants('src/main/python/apache/aurora/executor/common:executor_timeout'),
+    pants('src/main/python/apache/aurora/executor/common:health_checker'),
+    pants('src/main/python/apache/aurora/executor/common:sandbox'),
+    pants('src/main/python/apache/aurora/executor:executor_detector'),
+    pants('src/main/python/apache/aurora/executor:executor_vars'),
+    pants('src/main/python/apache/aurora/executor:thermos_executor'),
+    pants('src/main/python/apache/aurora/executor:thermos_task_runner'),
   ]
 )
 
 python_binary(
   name = 'gc_executor',
   source = 'gc_executor_main.py',
-  entry_point = 'twitter.aurora.executor.bin.gc_executor_main:proxy_main',
+  entry_point = 'apache.aurora.executor.bin.gc_executor_main:proxy_main',
   ignore_errors = True,
   always_write_cache = True,
   dependencies = [
     pants('aurora/twitterdeps/src/python/twitter/common/app'),
     pants('aurora/twitterdeps/src/python/twitter/common/log'),
     pants('aurora/twitterdeps/src/python/twitter/common/metrics'),
-    pants('src/main/python/twitter/thermos/common:path'),
-    pants('src/main/python/twitter/aurora/executor:executor_detector'),
-    pants('src/main/python/twitter/aurora/executor:executor_vars'),
-    pants('src/main/python/twitter/aurora/executor:gc_executor'),
+    pants('src/main/python/apache/thermos/common:path'),
+    pants('src/main/python/apache/aurora/executor:executor_detector'),
+    pants('src/main/python/apache/aurora/executor:executor_vars'),
+    pants('src/main/python/apache/aurora/executor:gc_executor'),
   ]
 )
 
 python_binary(
   name = 'thermos_runner',
   source = 'thermos_runner_main.py',
-  entry_point = 'twitter.aurora.executor.bin.thermos_runner_main:proxy_main',
+  entry_point = 'apache.aurora.executor.bin.thermos_runner_main:proxy_main',
   dependencies = [
     pants('aurora/twitterdeps/src/python/twitter/common/app'),
     pants('aurora/twitterdeps/src/python/twitter/common/log'),
-    pants('src/main/python/twitter/aurora/executor:thermos_runner'),
+    pants('src/main/python/apache/aurora/executor:thermos_runner'),
   ],
 )

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/executor/bin/gc_executor_main.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/executor/bin/gc_executor_main.py b/src/main/python/apache/aurora/executor/bin/gc_executor_main.py
index fad20e6..48ccbf6 100644
--- a/src/main/python/apache/aurora/executor/bin/gc_executor_main.py
+++ b/src/main/python/apache/aurora/executor/bin/gc_executor_main.py
@@ -5,12 +5,12 @@ slave.
 
 """
 
-from twitter.aurora.executor.executor_detector import ExecutorDetector
-from twitter.aurora.executor.gc_executor import ThermosGCExecutor
+from apache.aurora.executor.executor_detector import ExecutorDetector
+from apache.aurora.executor.gc_executor import ThermosGCExecutor
 from twitter.common import app, log
 from twitter.common.log.options import LogOptions
 from twitter.common.metrics.sampler import DiskMetricWriter
-from twitter.thermos.common.path import TaskPath
+from apache.thermos.common.path import TaskPath
 
 import mesos
 

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/executor/bin/thermos_executor_main.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/executor/bin/thermos_executor_main.py b/src/main/python/apache/aurora/executor/bin/thermos_executor_main.py
index 31e718e..d393968 100644
--- a/src/main/python/apache/aurora/executor/bin/thermos_executor_main.py
+++ b/src/main/python/apache/aurora/executor/bin/thermos_executor_main.py
@@ -10,10 +10,10 @@ import os
 from twitter.common import app, log
 from twitter.common.log.options import LogOptions
 
-from twitter.aurora.executor.common.executor_timeout import ExecutorTimeout
-from twitter.aurora.executor.common.health_checker import HealthCheckerProvider
-from twitter.aurora.executor.thermos_executor import ThermosExecutor
-from twitter.aurora.executor.thermos_task_runner import DefaultThermosTaskRunnerProvider
+from apache.aurora.executor.common.executor_timeout import ExecutorTimeout
+from apache.aurora.executor.common.health_checker import HealthCheckerProvider
+from apache.aurora.executor.thermos_executor import ThermosExecutor
+from apache.aurora.executor.thermos_task_runner import DefaultThermosTaskRunnerProvider
 
 import mesos
 
@@ -29,13 +29,13 @@ LogOptions.set_log_dir('.')
 # as a resource, shell out to one on the PATH.
 def dump_runner_pex():
   import pkg_resources
-  import twitter.aurora.executor.resources
+  import apache.aurora.executor.resources
   pex_name = 'thermos_runner.pex'
   runner_pex = os.path.join(os.path.realpath('.'), pex_name)
   with open(runner_pex, 'w') as fp:
     # TODO(wickman) Use shutil.copyfileobj to reduce memory footprint here.
     fp.write(pkg_resources.resource_stream(
-        twitter.aurora.executor.resources.__name__, pex_name).read())
+        apache.aurora.executor.resources.__name__, pex_name).read())
   return runner_pex
 
 

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/executor/bin/thermos_runner_main.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/executor/bin/thermos_runner_main.py b/src/main/python/apache/aurora/executor/bin/thermos_runner_main.py
index 602111e..33d22e4 100644
--- a/src/main/python/apache/aurora/executor/bin/thermos_runner_main.py
+++ b/src/main/python/apache/aurora/executor/bin/thermos_runner_main.py
@@ -1,6 +1,6 @@
 from twitter.common import app
 from twitter.common.log.options import LogOptions
-from twitter.aurora.executor.thermos_runner import proxy_main as runner_proxy_main
+from apache.aurora.executor.thermos_runner import proxy_main as runner_proxy_main
 
 
 LogOptions.set_simple(True)

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/executor/common/BUILD
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/executor/common/BUILD b/src/main/python/apache/aurora/executor/common/BUILD
index 9c932d1..54c7d22 100644
--- a/src/main/python/apache/aurora/executor/common/BUILD
+++ b/src/main/python/apache/aurora/executor/common/BUILD
@@ -25,7 +25,7 @@ python_library(
     pants(':task_info'),
     pants('aurora/twitterdeps/src/python/twitter/common/log'),
     pants('aurora/twitterdeps/src/python/twitter/common/exceptions'),
-    pants('src/main/python/twitter/aurora/common:http_signaler'),
+    pants('src/main/python/apache/aurora/common:http_signaler'),
   ]
 )
 
@@ -60,10 +60,10 @@ python_library(
   name = 'task_info',
   sources = ['task_info.py'],
   dependencies = [
-    pants('src/main/python/twitter/aurora/BUILD.thirdparty:pystachio'),
+    pants('src/main/python/apache/aurora/BUILD.thirdparty:pystachio'),
     pants('aurora/twitterdeps/src/python/twitter/common/log'),
-    pants('src/main/python/twitter/aurora/config'),
-    pants('src/main/python/twitter/aurora/config/schema'),
-    pants('src/main/thrift/com/twitter/aurora/gen:py-thrift'),
+    pants('src/main/python/apache/aurora/config'),
+    pants('src/main/python/apache/aurora/config/schema'),
+    pants('src/main/thrift/org/apache/aurora/gen:py-thrift'),
   ]
 )

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/executor/common/health_checker.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/executor/common/health_checker.py b/src/main/python/apache/aurora/executor/common/health_checker.py
index 3b25f0e..3f522b0 100644
--- a/src/main/python/apache/aurora/executor/common/health_checker.py
+++ b/src/main/python/apache/aurora/executor/common/health_checker.py
@@ -1,7 +1,7 @@
 import threading
 import time
 
-from twitter.aurora.common.http_signaler import HttpSignaler
+from apache.aurora.common.http_signaler import HttpSignaler
 from twitter.common import log
 from twitter.common.exceptions import ExceptionalThread
 

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/executor/common/task_info.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/executor/common/task_info.py b/src/main/python/apache/aurora/executor/common/task_info.py
index 1a7cf27..f36a045 100644
--- a/src/main/python/apache/aurora/executor/common/task_info.py
+++ b/src/main/python/apache/aurora/executor/common/task_info.py
@@ -1,11 +1,11 @@
 import json
 
-from twitter.aurora.config.port_resolver import PortResolver
-from twitter.aurora.config.schema.base import MesosJob, MesosTaskInstance
-from twitter.aurora.config.thrift import task_instance_from_job
+from apache.aurora.config.port_resolver import PortResolver
+from apache.aurora.config.schema.base import MesosJob, MesosTaskInstance
+from apache.aurora.config.thrift import task_instance_from_job
 from twitter.common import log
 
-from gen.twitter.aurora.ttypes import AssignedTask
+from gen.apache.aurora.ttypes import AssignedTask
 
 from pystachio import Ref
 from thrift.Thrift import TException

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/executor/executor_base.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/executor/executor_base.py b/src/main/python/apache/aurora/executor/executor_base.py
index 4fd9aa4..0cab2e5 100644
--- a/src/main/python/apache/aurora/executor/executor_base.py
+++ b/src/main/python/apache/aurora/executor/executor_base.py
@@ -1,8 +1,8 @@
 from twitter.common import log
 
-from gen.twitter.aurora.constants import TERMINAL_STATES as AURORA_TERMINAL_STATES
-from gen.twitter.aurora.ttypes import ScheduleStatus
-from gen.twitter.thermos.ttypes import TaskState
+from gen.apache.aurora.constants import TERMINAL_STATES as AURORA_TERMINAL_STATES
+from gen.apache.aurora.ttypes import ScheduleStatus
+from gen.apache.thermos.ttypes import TaskState
 
 import mesos
 import mesos_pb2 as mesos_pb

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/executor/gc_executor.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/executor/gc_executor.py b/src/main/python/apache/aurora/executor/gc_executor.py
index f17d0a2..c68181a 100644
--- a/src/main/python/apache/aurora/executor/gc_executor.py
+++ b/src/main/python/apache/aurora/executor/gc_executor.py
@@ -15,18 +15,18 @@ from twitter.common.exceptions import ExceptionalThread
 from twitter.common.metrics import Observable
 from twitter.common.metrics.gauge import AtomicGauge
 from twitter.common.quantity import Amount, Time
-from twitter.thermos.common.ckpt import CheckpointDispatcher
-from twitter.thermos.common.path import TaskPath
-from twitter.thermos.core.inspector import CheckpointInspector
-from twitter.thermos.core.helper import TaskKiller
-from twitter.thermos.monitoring.detector import TaskDetector
-from twitter.thermos.monitoring.garbage import TaskGarbageCollector
-
-from gen.twitter.aurora.comm.ttypes import (
+from apache.thermos.common.ckpt import CheckpointDispatcher
+from apache.thermos.common.path import TaskPath
+from apache.thermos.core.inspector import CheckpointInspector
+from apache.thermos.core.helper import TaskKiller
+from apache.thermos.monitoring.detector import TaskDetector
+from apache.thermos.monitoring.garbage import TaskGarbageCollector
+
+from gen.apache.aurora.comm.ttypes import (
     AdjustRetainedTasks,
     DeletedTasks,
     SchedulerMessage)
-from gen.twitter.aurora.ttypes import ScheduleStatus
+from gen.apache.aurora.ttypes import ScheduleStatus
 
 from .common.sandbox import DirectorySandbox, SandboxInterface
 from .executor_base import ThermosExecutorBase

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/executor/thermos_runner.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/executor/thermos_runner.py b/src/main/python/apache/aurora/executor/thermos_runner.py
index 0c9af05..fc706e7 100644
--- a/src/main/python/apache/aurora/executor/thermos_runner.py
+++ b/src/main/python/apache/aurora/executor/thermos_runner.py
@@ -5,10 +5,10 @@ import sys
 import traceback
 
 from twitter.common import app, log
-from twitter.thermos.common.options import add_port_to
-from twitter.thermos.common.planner import TaskPlanner
-from twitter.thermos.config.loader import ThermosConfigLoader
-from twitter.thermos.core.runner import TaskRunner
+from apache.thermos.common.options import add_port_to
+from apache.thermos.common.planner import TaskPlanner
+from apache.thermos.config.loader import ThermosConfigLoader
+from apache.thermos.core.runner import TaskRunner
 
 
 app.add_option(

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/executor/thermos_task_runner.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/executor/thermos_task_runner.py b/src/main/python/apache/aurora/executor/thermos_task_runner.py
index dba99d2..6ecb51a 100644
--- a/src/main/python/apache/aurora/executor/thermos_task_runner.py
+++ b/src/main/python/apache/aurora/executor/thermos_task_runner.py
@@ -6,17 +6,17 @@ import subprocess
 import threading
 import time
 
-from twitter.aurora.common.http_signaler import HttpSignaler
+from apache.aurora.common.http_signaler import HttpSignaler
 from twitter.common import log
 from twitter.common.dirutil import chmod_plus_x, safe_mkdtemp
 from twitter.common.log.options import LogOptions
 from twitter.common.quantity import Amount, Time
-from twitter.thermos.common.path import TaskPath
-from twitter.thermos.config.loader import ThermosTaskWrapper
-from twitter.thermos.core import runner as core
-from twitter.thermos.monitoring.monitor import TaskMonitor
+from apache.thermos.common.path import TaskPath
+from apache.thermos.config.loader import ThermosTaskWrapper
+from apache.thermos.core import runner as core
+from apache.thermos.monitoring.monitor import TaskMonitor
 
-from gen.twitter.thermos.ttypes import TaskState
+from gen.apache.thermos.ttypes import TaskState
 
 from .common.status_checker import ExitState, StatusResult
 from .common.task_info import (

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/tools/java/organize_imports.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/tools/java/organize_imports.py b/src/main/python/apache/aurora/tools/java/organize_imports.py
index 48a0821..6dce4c1 100644
--- a/src/main/python/apache/aurora/tools/java/organize_imports.py
+++ b/src/main/python/apache/aurora/tools/java/organize_imports.py
@@ -1,8 +1,7 @@
 #!/bin/env python
 '''
-Organizes a java source file's import statements in a way that pleases Twitter's checkstyle
-configuration.
-This expects exactly one argument: the name of the file to modify with preferred import
+Organizes a java source file's import statements in a way that pleases Apache Aurora's checkstyle
+configuration. This expects exactly one argument: the name of the file to modify with preferred import
 ordering.
 '''
 
@@ -18,10 +17,7 @@ def get_group(import_statement):
   matcher = IMPORT_RE.match(import_statement)
   assert matcher, 'Could not parse import statement: %s' % import_statement
   class_name = matcher.group(1)
-  if class_name.startswith('com.twitter'):
-    group = 'com.twitter'
-  else:
-    group = class_name.split('.')[0]
+  group = class_name.split('.')[0]
   return group
 
 
@@ -56,7 +52,7 @@ def get_all_group_lines(import_groups):
     return lines 
 
   all_lines = []
-  explicit_groups = ['java', 'javax', 'scala', 'com', 'net', 'org', 'com.twitter']
+  explicit_groups = ['java', 'javax', 'scala', 'com', 'net', 'org']
   for group in explicit_groups:
     if group in import_groups:
       all_lines += get_group_lines(group)

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/tools/java/thrift_wrapper_codegen.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/thermos/BUILD b/src/main/python/apache/thermos/BUILD
index 937bcf3..81a0c40 100644
--- a/src/main/python/apache/thermos/BUILD
+++ b/src/main/python/apache/thermos/BUILD
@@ -5,14 +5,14 @@ page(name = 'readme', source = 'README.md')
 python_library(
   name = 'thermos',
   dependencies = [
-    pants('src/main/python/twitter/thermos/core'),
-    pants('src/main/python/twitter/thermos/monitoring'),
+    pants('src/main/python/apache/thermos/core'),
+    pants('src/main/python/apache/thermos/monitoring'),
   ],
   provides = setup_py(
-    name = 'twitter.thermos',
+    name = 'apache.thermos',
     version = open(os.path.join(get_buildroot(), '.auroraversion')).read().strip().lower(),
-    descripton = 'The Twitter Thermos runtime.',
+    descripton = 'The Apache Aurora Thermos runtime.',
   ).with_binaries(
-    thermos = pants('src/main/python/twitter/thermos/bin:thermos'),
+    thermos = pants('src/main/python/apache/thermos/bin:thermos'),
   )
 )

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/thermos/README.md
----------------------------------------------------------------------
diff --git a/src/main/python/apache/thermos/README.md b/src/main/python/apache/thermos/README.md
index e456e93..4bfefd3 100644
--- a/src/main/python/apache/thermos/README.md
+++ b/src/main/python/apache/thermos/README.md
@@ -28,8 +28,8 @@ Thermos lives in `science` at Twitter and publically on GitHub in `twitter-commo
 Build the Thermos CLI and the Thermos observer.
 
 ```shell
-$ ./pants src/python/twitter/thermos
-$ ./pants src/python/twitter/thermos/bin:thermos_observe
+$ ./pants src/python/apache/thermos
+$ ./pants src/python/apache/thermos/bin:thermos_observe
 ```
 
 You can copy `dist/thermos.pex` to `thermos` somewhere in your `$PATH` or use a la carte.
@@ -131,7 +131,7 @@ export({
 ```
 
 The full Thermos pystachio schema can be found at
-`src/python/twitter/thermos/config/schema.py` and is mostly described below.
+`src/python/apache/thermos/config/schema.py` and is mostly described below.
 
 
 ## Configuration reference ##
@@ -351,11 +351,11 @@ mostly a best-effort signal.
 ## REPL ##
 
 You can interactively experiment with the Thermos configuration REPL via the
-`src/python/twitter/thermos/config:repl` target:
+`src/python/apache/thermos/config:repl` target:
 
 ```python
-$ ./pants py src/python/twitter/thermos/config:repl
-Build operating on target: PythonBinary(src/python/twitter/thermos/config/BUILD:repl)
+$ ./pants py src/python/apache/thermos/config:repl
+Build operating on target: PythonBinary(src/python/apache/thermos/config/BUILD:repl)
 Thermos Config REPL
 >>> boilerplate = Process(cmdline = "echo hello world")
 >>> boilerplate
@@ -397,7 +397,7 @@ If this is left unbound, the thermos CLI will complain:
 
 ```
 $ thermos run thermos/examples/tutorial/unbound.thermos
-twitter.thermos.config.loader.InvalidTask: Task[processes] failed: Element in ProcessList failed check: Process[cmdline] failed: Uninterpolated variables: {{first}}
+apache.thermos.config.loader.InvalidTask: Task[processes] failed: Element in ProcessList failed check: Process[cmdline] failed: Uninterpolated variables: {{first}}
 ```
 
 But free variables can be populated at runtime using the `-E` parameter:

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/thermos/bin/BUILD
----------------------------------------------------------------------
diff --git a/src/main/python/apache/thermos/bin/BUILD b/src/main/python/apache/thermos/bin/BUILD
index 5aa41a2..9d5e7e0 100644
--- a/src/main/python/apache/thermos/bin/BUILD
+++ b/src/main/python/apache/thermos/bin/BUILD
@@ -4,8 +4,8 @@ python_binary(
   dependencies = [
     pants('aurora/twitterdeps/src/python/twitter/common/app'),
     pants('aurora/twitterdeps/src/python/twitter/common/recordio:recordio-thrift'),
-    pants('src/main/python/twitter/thermos/common'),
-    pants('src/main/thrift/com/twitter/thermos:py-thrift')
+    pants('src/main/python/apache/thermos/common'),
+    pants('src/main/thrift/org/apache/thermos:py-thrift')
   ]
 )
 
@@ -15,10 +15,10 @@ python_binary(
   dependencies = [
     pants('aurora/twitterdeps/src/python/twitter/common/app'),
     pants('aurora/twitterdeps/src/python/twitter/common/log'),
-    pants('src/main/python/twitter/thermos/common'),
-    pants('src/main/python/twitter/thermos/config:schema'),
-    pants('src/main/python/twitter/thermos/core'),
-    pants('src/main/python/twitter/thermos/monitoring'),
-    pants('src/main/thrift/com/twitter/thermos:py-thrift'),
+    pants('src/main/python/apache/thermos/common'),
+    pants('src/main/python/apache/thermos/config:schema'),
+    pants('src/main/python/apache/thermos/core'),
+    pants('src/main/python/apache/thermos/monitoring'),
+    pants('src/main/thrift/org/apache/thermos:py-thrift'),
   ],
 )

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/thermos/bin/thermos.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/thermos/bin/thermos.py b/src/main/python/apache/thermos/bin/thermos.py
index 5e695b4..334297a 100644
--- a/src/main/python/apache/thermos/bin/thermos.py
+++ b/src/main/python/apache/thermos/bin/thermos.py
@@ -18,21 +18,21 @@ from twitter.common.dirutil.tail import tail as tail_closed
 from twitter.common.quantity import Amount, Time, Data
 from twitter.common.quantity.parse_simple import parse_time, parse_data
 from twitter.common.recordio import RecordIO, ThriftRecordReader
-from twitter.thermos.common.path import TkPath
-from twitter.thermos.common.ckpt import CheckpointDispatcher
-from twitter.thermos.common.options import add_port_to, add_binding_to
-from twitter.thermos.config.loader import ThermosConfigLoader, ThermosTaskWrapper
-from twitter.thermos.config.schema import (
+from apache.thermos.common.path import TkPath
+from apache.thermos.common.ckpt import CheckpointDispatcher
+from apache.thermos.common.options import add_port_to, add_binding_to
+from apache.thermos.config.loader import ThermosConfigLoader, ThermosTaskWrapper
+from apache.thermos.config.schema import (
   Process,
   Resources,
   Task)
-from twitter.thermos.core.helper import TaskRunnerHelper
-from twitter.thermos.core.runner import TaskRunner
-from twitter.thermos.monitoring.detector import TaskDetector
-from twitter.thermos.monitoring.garbage import TaskGarbageCollector, DefaultCollector
-from twitter.thermos.monitoring.monitor import TaskMonitor
+from apache.thermos.core.helper import TaskRunnerHelper
+from apache.thermos.core.runner import TaskRunner
+from apache.thermos.monitoring.detector import TaskDetector
+from apache.thermos.monitoring.garbage import TaskGarbageCollector, DefaultCollector
+from apache.thermos.monitoring.monitor import TaskMonitor
 
-from gen.twitter.thermos.ttypes import (
+from gen.apache.thermos.ttypes import (
   ProcessState,
   RunnerCkpt,
   RunnerState,

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/thermos/bin/thermos_ckpt.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/thermos/bin/thermos_ckpt.py b/src/main/python/apache/thermos/bin/thermos_ckpt.py
old mode 100755
new mode 100644
index 36fd419..fa9414f
--- a/src/main/python/apache/thermos/bin/thermos_ckpt.py
+++ b/src/main/python/apache/thermos/bin/thermos_ckpt.py
@@ -3,11 +3,11 @@ import sys
 import pprint
 import time
 
-from gen.twitter.thermos.ttypes import RunnerState, RunnerCkpt, TaskState
+from gen.apache.thermos.ttypes import RunnerState, RunnerCkpt, TaskState
 
 from twitter.common import app
 from twitter.common.recordio import RecordIO, ThriftRecordReader
-from twitter.thermos.common.ckpt import CheckpointDispatcher
+from apache.thermos.common.ckpt import CheckpointDispatcher
 
 app.add_option("--checkpoint", dest = "ckpt", metavar = "CKPT",
                help = "read checkpoint from CKPT")

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/thermos/common/BUILD
----------------------------------------------------------------------
diff --git a/src/main/python/apache/thermos/common/BUILD b/src/main/python/apache/thermos/common/BUILD
index d97c771..006147c 100644
--- a/src/main/python/apache/thermos/common/BUILD
+++ b/src/main/python/apache/thermos/common/BUILD
@@ -6,7 +6,7 @@ python_library(
   dependencies = [
     pants('aurora/twitterdeps/src/python/twitter/common/log'),
     pants('aurora/twitterdeps/src/python/twitter/common/recordio:recordio-thrift'),
-    pants('src/main/thrift/com/twitter/thermos:py-thrift')
+    pants('src/main/thrift/org/apache/thermos:py-thrift')
   ]
 )
 
@@ -24,8 +24,8 @@ python_library(
   name = 'options',
   sources = ['options.py'],
   dependencies = [
-    pants('src/main/python/twitter/thermos:pystachio'),
-    pants('src/main/thrift/com/twitter/thermos:py-thrift'),
+    pants('src/main/python/apache/thermos:pystachio'),
+    pants('src/main/thrift/org/apache/thermos:py-thrift'),
   ]
 )
 
@@ -38,7 +38,7 @@ python_library(
     pants(':planner'),
   ],
   provides = setup_py(
-    name = 'twitter.thermos.common',
+    name = 'apache.thermos.common',
     version = open(os.path.join(get_buildroot(), '.auroraversion')).read().strip().lower(),
     description = 'Thermos common libraries.',
   )

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/thermos/common/ckpt.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/thermos/common/ckpt.py b/src/main/python/apache/thermos/common/ckpt.py
index 9c5a949..da00c21 100644
--- a/src/main/python/apache/thermos/common/ckpt.py
+++ b/src/main/python/apache/thermos/common/ckpt.py
@@ -12,7 +12,7 @@ import os
 
 from twitter.common import log
 from twitter.common.recordio import RecordIO, ThriftRecordReader
-from gen.twitter.thermos.ttypes import (
+from gen.apache.thermos.ttypes import (
   ProcessState,
   ProcessStatus,
   RunnerCkpt,

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/thermos/config/BUILD
----------------------------------------------------------------------
diff --git a/src/main/python/apache/thermos/config/BUILD b/src/main/python/apache/thermos/config/BUILD
index 57e7f0d..084efed 100644
--- a/src/main/python/apache/thermos/config/BUILD
+++ b/src/main/python/apache/thermos/config/BUILD
@@ -5,8 +5,8 @@ python_library(
   sources = globs('*.py'),
   dependencies = [
     pants('aurora/twitterdeps/src/python/twitter/common/lang'),
-    pants('src/main/python/twitter/thermos:pystachio'),
-    pants('src/main/python/twitter/thermos/common:planner')
+    pants('src/main/python/apache/thermos:pystachio'),
+    pants('src/main/python/apache/thermos/common:planner')
   ],
 )
 
@@ -14,10 +14,10 @@ python_library(
   name = 'config',
   dependencies = [
     pants(':schema'),
-    pants('src/main/python/twitter/thermos/common'),  # cover common:planner
+    pants('src/main/python/apache/thermos/common'),  # cover common:planner
   ],
   provides = setup_py(
-    name = 'twitter.thermos.config',
+    name = 'apache.thermos.config',
     version = open(os.path.join(get_buildroot(), '.auroraversion')).read().strip().lower(),
     description = 'Thermos configuration schema and loader.',
   )

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/thermos/config/bin/config_load.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/thermos/config/bin/config_load.py b/src/main/python/apache/thermos/config/bin/config_load.py
index c0680ec..4af0163 100644
--- a/src/main/python/apache/thermos/config/bin/config_load.py
+++ b/src/main/python/apache/thermos/config/bin/config_load.py
@@ -4,7 +4,7 @@ import json
 import pprint
 
 from twitter.common import app
-from twitter.thermos.config.loader import ThermosConfigLoader
+from apache.thermos.config.loader import ThermosConfigLoader
 
 def main(args):
   """

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/thermos/config/bin/config_repl.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/thermos/config/bin/config_repl.py b/src/main/python/apache/thermos/config/bin/config_repl.py
index 4a5c797..4ba9667 100644
--- a/src/main/python/apache/thermos/config/bin/config_repl.py
+++ b/src/main/python/apache/thermos/config/bin/config_repl.py
@@ -1,3 +1,3 @@
-from twitter.thermos.config.schema import *
+from apache.thermos.config.schema import *
 from code import interact
 interact('Thermos Config REPL', local=locals())

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/thermos/config/loader.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/thermos/config/loader.py b/src/main/python/apache/thermos/config/loader.py
index 54721c3..4499d43 100644
--- a/src/main/python/apache/thermos/config/loader.py
+++ b/src/main/python/apache/thermos/config/loader.py
@@ -6,8 +6,8 @@ import textwrap
 
 from twitter.common.dirutil import safe_open
 from twitter.common.lang import Compatibility
-from twitter.thermos.common.planner import TaskPlanner
-from twitter.thermos.config.schema import Task
+from apache.thermos.common.planner import TaskPlanner
+from apache.thermos.config.schema import Task
 
 from pystachio import Ref
 from pystachio.config import Config
@@ -147,7 +147,7 @@ class ThermosTaskValidator(object):
 class ThermosConfigLoader(object):
   SCHEMA = textwrap.dedent("""
     from pystachio import *
-    from twitter.thermos.config.schema import *
+    from apache.thermos.config.schema import *
 
     __TASKS = []
 

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/thermos/core/BUILD
----------------------------------------------------------------------
diff --git a/src/main/python/apache/thermos/core/BUILD b/src/main/python/apache/thermos/core/BUILD
index d260112..0515e03 100644
--- a/src/main/python/apache/thermos/core/BUILD
+++ b/src/main/python/apache/thermos/core/BUILD
@@ -4,14 +4,14 @@ python_library(
   name = 'helper',
   sources = ['helper.py'],
   dependencies = [
-    pants('src/main/python/twitter/thermos:psutil'),
+    pants('src/main/python/apache/thermos:psutil'),
     pants('aurora/twitterdeps/src/python/twitter/common/dirutil'),
     pants('aurora/twitterdeps/src/python/twitter/common/log'),
     pants('aurora/twitterdeps/src/python/twitter/common/quantity'),
     pants('aurora/twitterdeps/src/python/twitter/common/recordio:recordio-thrift'),
-    pants('src/main/python/twitter/thermos/common:ckpt'),
-    pants('src/main/python/twitter/thermos/common:path'),
-    pants('src/main/thrift/com/twitter/thermos:py-thrift'),
+    pants('src/main/python/apache/thermos/common:ckpt'),
+    pants('src/main/python/apache/thermos/common:path'),
+    pants('src/main/thrift/org/apache/thermos:py-thrift'),
   ]
 )
 
@@ -21,9 +21,9 @@ python_library(
   dependencies = [
     pants(':muxer'),
     pants('aurora/twitterdeps/src/python/twitter/common/recordio:recordio-thrift'),
-    pants('src/main/python/twitter/thermos/common:ckpt'),
-    pants('src/main/python/twitter/thermos/common:path'),
-    pants('src/main/thrift/com/twitter/thermos:py-thrift'),
+    pants('src/main/python/apache/thermos/common:ckpt'),
+    pants('src/main/python/apache/thermos/common:path'),
+    pants('src/main/thrift/org/apache/thermos:py-thrift'),
   ]
 )
 
@@ -33,7 +33,7 @@ python_library(
   dependencies = [
     pants('aurora/twitterdeps/src/python/twitter/common/log'),
     pants('aurora/twitterdeps/src/python/twitter/common/recordio:recordio-thrift'),
-    pants('src/main/thrift/com/twitter/thermos:py-thrift'),
+    pants('src/main/thrift/org/apache/thermos:py-thrift'),
   ]
 )
 
@@ -46,7 +46,7 @@ python_library(
     pants('aurora/twitterdeps/src/python/twitter/common/log'),
     pants('aurora/twitterdeps/src/python/twitter/common/quantity'),
     pants('aurora/twitterdeps/src/python/twitter/common/recordio:recordio-thrift'),
-    pants('src/main/thrift/com/twitter/thermos:py-thrift'),
+    pants('src/main/thrift/org/apache/thermos:py-thrift'),
   ]
 )
 
@@ -61,12 +61,12 @@ python_library(
     pants('aurora/twitterdeps/src/python/twitter/common/log'),
     pants('aurora/twitterdeps/src/python/twitter/common/quantity'),
     pants('aurora/twitterdeps/src/python/twitter/common/recordio:recordio-thrift'),
-    pants('src/main/python/twitter/thermos:psutil'),
-    pants('src/main/python/twitter/thermos/common:ckpt'),
-    pants('src/main/python/twitter/thermos/common:path'),
-    pants('src/main/python/twitter/thermos/common:planner'),
-    pants('src/main/python/twitter/thermos/config:schema'),
-    pants('src/main/thrift/com/twitter/thermos:py-thrift'),
+    pants('src/main/python/apache/thermos:psutil'),
+    pants('src/main/python/apache/thermos/common:ckpt'),
+    pants('src/main/python/apache/thermos/common:path'),
+    pants('src/main/python/apache/thermos/common:planner'),
+    pants('src/main/python/apache/thermos/config:schema'),
+    pants('src/main/thrift/org/apache/thermos:py-thrift'),
   ]
 )
 
@@ -77,11 +77,11 @@ python_library(
     pants(':runner'),
 
     # covering libs
-    pants('src/main/python/twitter/thermos/common'),
-    pants('src/main/python/twitter/thermos/config'),
+    pants('src/main/python/apache/thermos/common'),
+    pants('src/main/python/apache/thermos/config'),
   ],
   provides = setup_py(
-    name = 'twitter.thermos.core',
+    name = 'apache.thermos.core',
     version = open(os.path.join(get_buildroot(), '.auroraversion')).read().strip().lower(),
     description = 'The Thermos core state machine.',
   )

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/thermos/core/helper.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/thermos/core/helper.py b/src/main/python/apache/thermos/core/helper.py
index 3587a85..8c954bc 100644
--- a/src/main/python/apache/thermos/core/helper.py
+++ b/src/main/python/apache/thermos/core/helper.py
@@ -8,10 +8,10 @@ from twitter.common import log
 from twitter.common.dirutil import lock_file, safe_mkdir
 from twitter.common.quantity import Amount, Time
 from twitter.common.recordio import ThriftRecordWriter
-from twitter.thermos.common.ckpt import CheckpointDispatcher
-from twitter.thermos.common.path import TaskPath
+from apache.thermos.common.ckpt import CheckpointDispatcher
+from apache.thermos.common.path import TaskPath
 
-from gen.twitter.thermos.ttypes import (
+from gen.apache.thermos.ttypes import (
   ProcessState,
   ProcessStatus,
   RunnerCkpt,

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/thermos/core/inspector.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/thermos/core/inspector.py b/src/main/python/apache/thermos/core/inspector.py
index 8c646a1..ad9213e 100644
--- a/src/main/python/apache/thermos/core/inspector.py
+++ b/src/main/python/apache/thermos/core/inspector.py
@@ -5,10 +5,10 @@ import pwd
 from twitter.common import log
 from twitter.common.recordio import RecordIO, ThriftRecordReader
 
-from twitter.thermos.common.ckpt import CheckpointDispatcher
-from twitter.thermos.common.path import TaskPath
+from apache.thermos.common.ckpt import CheckpointDispatcher
+from apache.thermos.common.path import TaskPath
 
-from gen.twitter.thermos.ttypes import (
+from gen.apache.thermos.ttypes import (
   ProcessState,
   RunnerCkpt,
   RunnerState)

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/thermos/core/muxer.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/thermos/core/muxer.py b/src/main/python/apache/thermos/core/muxer.py
index 9c0b389..7588dca 100644
--- a/src/main/python/apache/thermos/core/muxer.py
+++ b/src/main/python/apache/thermos/core/muxer.py
@@ -3,7 +3,7 @@ import errno
 
 from twitter.common import log
 from twitter.common.recordio import ThriftRecordReader
-from gen.twitter.thermos.ttypes import RunnerCkpt
+from gen.apache.thermos.ttypes import RunnerCkpt
 
 
 class ProcessMuxer(object):

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/thermos/core/process.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/thermos/core/process.py b/src/main/python/apache/thermos/core/process.py
index dd1d62a..a87a6e0 100644
--- a/src/main/python/apache/thermos/core/process.py
+++ b/src/main/python/apache/thermos/core/process.py
@@ -26,7 +26,7 @@ from twitter.common.lang import Interface
 from twitter.common.quantity import Amount, Time
 from twitter.common.recordio import ThriftRecordReader, ThriftRecordWriter
 
-from gen.twitter.thermos.ttypes import (
+from gen.apache.thermos.ttypes import (
     ProcessState,
     ProcessStatus,
     RunnerCkpt,

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/thermos/core/runner.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/thermos/core/runner.py b/src/main/python/apache/thermos/core/runner.py
index b10cf16..9466ab4 100644
--- a/src/main/python/apache/thermos/core/runner.py
+++ b/src/main/python/apache/thermos/core/runner.py
@@ -39,21 +39,21 @@ from twitter.common.dirutil import safe_mkdir
 from twitter.common.quantity import Amount, Time
 from twitter.common.recordio import ThriftRecordReader
 
-from twitter.thermos.common.ckpt import (
+from apache.thermos.common.ckpt import (
   CheckpointDispatcher,
   UniversalStateHandler,
   ProcessStateHandler,
   TaskStateHandler)
-from twitter.thermos.common.path import TaskPath
-from twitter.thermos.common.planner import TaskPlanner
-from twitter.thermos.config.loader import (
+from apache.thermos.common.path import TaskPath
+from apache.thermos.common.planner import TaskPlanner
+from apache.thermos.config.loader import (
   ThermosConfigLoader,
   ThermosProcessWrapper,
   ThermosTaskWrapper,
   ThermosTaskValidator)
-from twitter.thermos.config.schema import ThermosContext
+from apache.thermos.config.schema import ThermosContext
 
-from gen.twitter.thermos.ttypes import (
+from gen.apache.thermos.ttypes import (
   ProcessState,
   ProcessStatus,
   RunnerCkpt,

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/thermos/monitoring/BUILD
----------------------------------------------------------------------
diff --git a/src/main/python/apache/thermos/monitoring/BUILD b/src/main/python/apache/thermos/monitoring/BUILD
index a977878..f5b1b0e 100644
--- a/src/main/python/apache/thermos/monitoring/BUILD
+++ b/src/main/python/apache/thermos/monitoring/BUILD
@@ -4,7 +4,7 @@ python_library(
   name = 'detector',
   sources = ['detector.py'],
   dependencies = [
-    pants('src/main/python/twitter/thermos/common:path')
+    pants('src/main/python/apache/thermos/common:path')
   ]
 )
 
@@ -16,8 +16,8 @@ python_library(
     pants('aurora/twitterdeps/src/python/twitter/common/dirutil'),
     pants('aurora/twitterdeps/src/python/twitter/common/lang'),
     pants('aurora/twitterdeps/src/python/twitter/common/quantity'),
-    pants('src/main/python/twitter/thermos/common:ckpt'),
-    pants('src/main/python/twitter/thermos/common:path'),
+    pants('src/main/python/apache/thermos/common:ckpt'),
+    pants('src/main/python/apache/thermos/common:path'),
   ]
 )
 
@@ -27,8 +27,8 @@ python_library(
   dependencies = [
     pants('aurora/twitterdeps/src/python/twitter/common/log'),
     pants('aurora/twitterdeps/src/python/twitter/common/recordio:recordio-thrift'),
-    pants('src/main/python/twitter/thermos/common:ckpt'),
-    pants('src/main/thrift/com/twitter/thermos:py-thrift'),
+    pants('src/main/python/apache/thermos/common:ckpt'),
+    pants('src/main/thrift/org/apache/thermos:py-thrift'),
   ]
 )
 
@@ -56,7 +56,7 @@ python_library(
   dependencies = [
     pants(':process'),
     pants('aurora/twitterdeps/src/python/twitter/common/log'),
-    pants('src/main/python/twitter/thermos:psutil'),
+    pants('src/main/python/apache/thermos:psutil'),
   ]
 )
 
@@ -87,10 +87,10 @@ python_library(
     pants(':resource'),
 
     # covering dependency for common
-    pants('src/main/python/twitter/thermos/common'),
+    pants('src/main/python/apache/thermos/common'),
   ],
   provides = setup_py(
-    name = 'twitter.thermos.monitoring',
+    name = 'apache.thermos.monitoring',
     version = open(os.path.join(get_buildroot(), '.auroraversion')).read().strip().lower(),
     description = 'Thermos monitoring library.',
   )

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/thermos/monitoring/detector.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/thermos/monitoring/detector.py b/src/main/python/apache/thermos/monitoring/detector.py
index ed48c93..f2c59ce 100644
--- a/src/main/python/apache/thermos/monitoring/detector.py
+++ b/src/main/python/apache/thermos/monitoring/detector.py
@@ -8,7 +8,7 @@ import glob
 import os
 import re
 
-from twitter.thermos.common.path import TaskPath
+from apache.thermos.common.path import TaskPath
 
 
 class TaskDetector(object):
diff --git a/src/main/python/apache/aurora/client/hooks/hooked_api.py b/src/main/python/apache/aurora/client/hooks/hooked_api.py
index cc4d3db..da71af4 100644
--- a/src/main/python/apache/aurora/client/hooks/hooked_api.py
+++ b/src/main/python/apache/aurora/client/hooks/hooked_api.py
@@ -2,10 +2,10 @@ import functools
 import traceback
 
 from twitter.common import log
-from twitter.aurora.client.api import AuroraClientAPI
-from twitter.aurora.common.aurora_job_key import AuroraJobKey
+from apache.aurora.client.api import AuroraClientAPI
+from apache.aurora.common.aurora_job_key import AuroraJobKey
 
-from gen.twitter.aurora.ttypes import ResponseCode
+from gen.apache.aurora.ttypes import ResponseCode
 
 
 def _partial(function, *args, **kw):
@@ -50,7 +50,7 @@ class NonHookedAuroraClientAPI(AuroraClientAPI):
 class HookedAuroraClientAPI(NonHookedAuroraClientAPI):
   """
     Adds a hooking aspect/behaviour to the lifecycle of Mesos Client API methods
     by injecting hooks (instances of twitter.aurora.client.hooks.Hooks)
 
     * Hooks are available in the 'config' (AuroraConfig) param that each API call receives
     * Each Hook is run around each API call:

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/client/options.py
----------------------------------------------------------------------
@@ -50,7 +50,7 @@ class NonHookedAuroraClientAPI(AuroraClientAPI):
   """
     Adds a hooking aspect/behaviour to the lifecycle of Mesos Client API methods
-    by injecting hooks (instances of twitter.aurora.client.hooks.Hooks)
+    by injecting hooks (instances of apache.aurora.client.hooks.Hooks)
 
     * Hooks are available in the 'config' (AuroraConfig) param that each API call receives
diff --git a/src/main/python/apache/aurora/tools/java/thrift_wrapper_codegen.py b/src/main/python/apache/aurora/tools/java/thrift_wrapper_codegen.py
index 4376e85..ec3ac20 100644
--- a/src/main/python/apache/aurora/tools/java/thrift_wrapper_codegen.py
+++ b/src/main/python/apache/aurora/tools/java/thrift_wrapper_codegen.py
@@ -110,10 +110,10 @@ STRUCT_COLLECTION_FIELD_ASSIGNMENT = '''this.%(field)s = !wrapped.%(isset)s()
               .transform(%(params)s.FROM_BUILDER)
               .to%(collection)s();'''
 
-PACKAGE_NAME = 'com.twitter.aurora.scheduler.storage.entities'
+PACKAGE_NAME = 'org.apache.aurora.scheduler.storage.entities'
 
 CLASS_TEMPLATE = '''/*
- * Copyright 2013 Twitter, Inc.
+ * Copyright 2013 Apache Software Foundation
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -263,7 +263,7 @@ class GeneratedCode(object):
 
 
 # A namespace declaration, e.g.:
 #    namespace java com.twitter.aurora.gen
 NAMESPACE_RE = 'namespace\s+(?P<lang>\w+)\s+(?P<namespace>[^\s]+)'
 
 # A possibly-parameterized type name, e.g.:

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/thermos/BUILD
----------------------------------------------------------------------
@@ -263,7 +263,7 @@ class GeneratedCode(object):
 
 # A namespace declaration, e.g.:
-#    namespace java com.twitter.aurora.gen
+#    namespace java org.apache.aurora.gen
 NAMESPACE_RE = 'namespace\s+(?P<lang>\w+)\s+(?P<namespace>[^\s]+)'
 